import React, { useState, useCallback, useEffect } from 'react';
import ReactDOM from 'react-dom';
import { csv, arc, pie, scaleBand, scaleLinear, max, format } from 'd3';
import { useData } from './useData';
import { AxisBottom } from './AxisBottom';
import { AxisLeft } from './AxisLeft';
import { Marks } from './Marks';
import { Dropdown } from './Dropdown';


const App = () => {
 const data = useData(); 

 // setting up Dropdown
  const initialYAttribute = 2019;
  const [yAttribute, setYAttribute] = useState(initialYAttribute);
  const yValue = d => d[yAttribute];
  
  if (!data) {
    return <pre>Loading...</pre>;
  }
  
const width = 900;
const height = 500;
const margin = { top: 40, right: 30, bottom: 85, left: 80 };
const xAxisLabelOffset = 50;
const innerHeight = height - margin.top - margin.bottom;
const innerWidth = width - margin.left - margin.right;
const bottomSpace = margin.bottom + margin.top;
const siFormat = format('.2s');
const yAxisTickFormat = tickValue => siFormat(tickValue).replace('G', 'B');
//const xAxisTickFormat = tickValue => siFormat(tickValue).replace('G', 'B');

//Dropdown features
const options = [
  {value: "2008", label: "2008"}, 
  {value: "2009", label: "2009"},
  {value: "2010", label: "2010"},
  {value: "2011", label: "2011"},
  {value: "2012", label: "2012"},
  {value: "2013", label: "2013"},
  {value: "2014", label: "2014"},
  {value: "2015", label: "2015"},
  {value: "2016", label: "2016"},
  {value: "2017", label: "2017"},
  {value: "2018", label: "2018"},
  {value: "2019", label: "2019"}
];
  
  
  const xValue = d => d.Countries;

  const xScale = scaleBand()
    .domain(data.map(xValue))
    .range([0, innerWidth])
    .paddingInner(0.15);
  const yScale = scaleLinear()
  	.domain([max(data, yValue),0])
  	.range([0, innerHeight]);
  
  
  
  return (
    <>
    <label for="y-select">Immigration numbers in the year:</label>
    <Dropdown 
      options={options} 
      id = "y-select" 
      selectedValue={yAttribute}
      onSelectedValueChange = {setYAttribute}/>
    <svg width={width} height={height}>
      <g transform={`translate(${margin.left},${margin.top})`}>
        <AxisLeft
          yScale={yScale}
          innerHeight={innerHeight}
          tickFormat={yAxisTickFormat}
        />
        <AxisBottom xScale={xScale} />
        <text
          className="axis-label"
          x={innerWidth / 2}
          y={innerHeight + xAxisLabelOffset}
          textAnchor="middle"> {xValue}
        </text>
        <Marks
          data={data}
          xScale={xScale}
          yScale={yScale}
          xValue={xValue}
          yValue={yValue}
          tooltipFormat={yAxisTickFormat}
        />
      </g>
    </svg>
    </>
  );
};
const rootElement = document.getElementById('root');
ReactDOM.render(<App />, rootElement);

